@@ -446,7 +446,7 @@ void KGrGame::initGame()
     // If he/she has never played before, set it to Tutorial, level 1.
     KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
     QString prevGamePrefix = gameGroup.readEntry ("GamePrefix", "tute");
-    int prevLevel          = gameGroup.readEntry (QStringLiteral("Level_") + prevGamePrefix, 1);
+    int prevLevel          = gameGroup.readEntry (QLatin1String("Level_") + prevGamePrefix, 1);
 
     //qCDebug(KGOLDRUNNER_LOG)<< "Config() Game and Level" << prevGamePrefix << prevLevel;
 
@@ -523,14 +523,14 @@ void KGrGame::initGame()
 bool KGrGame::getRecordingName (const QString & dir, const QString & pPrefix,
                                 QString & filename)
 {
-    QString recFile = dir + QStringLiteral("rec_") + pPrefix + QStringLiteral(".txt");
+    QString recFile = dir + QLatin1String("rec_") + pPrefix + QLatin1String(".txt");
     QFileInfo fileInfo (recFile);
     bool recOK = fileInfo.exists() && fileInfo.isReadable();
     filename = QString ();
 
     if (demoType == SOLVE) {
 	// Look for a solution-file name in User or System area.
-    QString solFile = dir + QStringLiteral("sol_") + pPrefix + QStringLiteral(".txt");
+    QString solFile = dir + QLatin1String("sol_") + pPrefix + QLatin1String(".txt");
 	fileInfo.setFile (solFile);
 	bool solOK = fileInfo.exists() && fileInfo.isReadable();
 	if (solOK) {
@@ -1483,8 +1483,8 @@ void KGrGame::saveGame()		// Save game ID, score and level.
     QTime now =   QTime::currentTime();
     QString saved;
     QString day;
-    day = today.shortDayName (today.dayOfWeek());
-    saved = saved.sprintf
+    day = QLocale().dayName(today.dayOfWeek(), QLocale::ShortFormat);
+    saved = QString::asprintf
                 ("%-6s %03d %03ld %7ld    %s %04d-%02d-%02d %02d:%02d\n",
                 qPrintable(prefix), level, lives, startScore,
                 qPrintable(day),
@@ -1573,7 +1573,7 @@ bool KGrGame::selectSavedGame (int & selectedGame, int & selectedLevel)
     selectedLevel = 0;
     if (! loadedData.isEmpty()) {
         pr = loadedData.mid (21, 7);			// Get the game prefix.
-        pr = pr.left (pr.indexOf (QStringLiteral(" "), 0, Qt::CaseInsensitive));
+        pr = pr.left (pr.indexOf(QLatin1Char(' '), 0, Qt::CaseInsensitive));
 
         for (int i = 0; i < gameList.count(); i++) {	// Find the game.
             if (gameList.at (i)->prefix == pr) {
@@ -1755,8 +1755,8 @@ void KGrGame::checkHighScore()
 
     QDate today = QDate::currentDate();
     QString hsDate;
-    QString day = today.shortDayName (today.dayOfWeek());
-    hsDate = hsDate.sprintf
+    QString day = QLocale().dayName(today.dayOfWeek(), QLocale::ShortFormat);
+    hsDate = QString::asprintf
                 ("%s %04d-%02d-%02d",
                 qPrintable(day),
                 today.year(), today.month(), today.day());
